_exceptions.py
changeset 9517 3338b2205ea3
parent 9375 8e88576787c3
child 9543 39f981482e34
--- a/_exceptions.py	Thu Feb 13 15:11:07 2014 +0100
+++ b/_exceptions.py	Tue Feb 11 11:03:01 2014 +0100
@@ -187,9 +187,9 @@
     :param txuuid: Unique identifier of the partialy undone transaction
 
     :type errors: list
     :param errors: List of errors occured during undoing
     """
-    msg = u"The following error(s) occured while undoing transaction #%d : %s"
+    msg = u"The following error(s) occurred while undoing transaction #%d : %s"
 
     def __init__(self, txuuid, errors):
         super(UndoTransactionException, self).__init__(txuuid, errors)
@@ -187,9 +187,9 @@
 
     :type errors: list
-    :param errors: List of errors occured during undoing
+    :param errors: List of errors occurred during undoing
     """